==> owncloud_7.0.4+dfsg.orig.tar.bz2: owncloud/core/l10n/sl.php <==
<?php
$TRANSLATIONS = array(
"Expiration date is in the past." => "Datum preteka je v preteklosti.",
"Couldn't send mail to following users: %s " => "Ni mogoče poslati sporočila za: %s",
"Turned on maintenance mode" => "Vzdrževalni način je omogočen",
"Turned off maintenance mode" => "Vzdrževalni način je onemogočen",
"Updated database" => "Posodobljena podatkovna zbirka",
"Disabled incompatible apps: %s" => "Onemogočeni neskladni programi: %s",
"No image or file provided" => "Ni podane datoteke ali slike",
"Unknown filetype" => "Neznana vrsta datoteke",
"Invalid image" => "Neveljavna slika",
"No temporary profile picture available, try again" => "Na voljo ni nobene začasne slike za profil. Poskusite znova.",
"No crop data provided" => "Ni podanih podatkov obreza",
"Sunday" => "nedelja",
"Monday" => "ponedeljek",
"Tuesday" => "torek",
"Wednesday" => "sreda",
"Thursday" => "četrtek",
"Friday" => "petek",
"Saturday" => "sobota",
"January" => "januar",
"February" => "februar",
"March" => "marec",
"April" => "april",
"May" => "maj",
"June" => "junij",
"July" => "julij",
"August" => "avgust",
"September" => "september",
"October" => "oktober",
"November" => "november",
"December" => "december",
"Settings" => "Nastavitve",
"File" => "Datoteka",
"Folder" => "Mapa",
"Image" => "Slika",
"Audio" => "Zvok",
"Saving..." => "Poteka shranjevanje ...",
"seconds ago" => "pred nekaj sekundami",
"_%n minute ago_::_%n minutes ago_" => array("pred %n minuto","pred %n minutama","pred %n minutami","pred %n minutami"),
"_%n hour ago_::_%n hours ago_" => array("pred %n uro","pred %n urama","pred %n urami","pred %n urami"),
"today" => "danes",
"yesterday" => "včeraj",
"_%n day ago_::_%n days ago_" => array("pred %n dnevom","pred %n dnevoma","pred %n dnevi","pred %n dnevi"),
"last month" => "zadnji mesec",
"_%n month ago_::_%n months ago_" => array("pred %n mesecem","pred %n mesecema","pred %n meseci","pred %n meseci"),
"last year" => "lansko leto",
"years ago" => "let nazaj",
"Reset password" => "Ponastavi geslo",
"Password can not be changed. Please contact your administrator." => "Gesla ni mogoče spremeniti. Stopite v stik s skrbnikom.",
"Yes" => "Da",
"No" => "Ne",
"Choose" => "Izbor",
"Error loading file picker template: {error}" => "Napaka nalaganja predloge izbirnika datotek: {error}",
"Ok" => "V redu",
"Error loading message template: {error}" => "Napaka nalaganja predloge sporočil: {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} spor datotek","{count} spora datotek","{count} spori datotek","{count} sporov datotek"),
"One file conflict" => "En spor datotek",
"New Files" => "Nove datoteke",
"Already existing files" => "Obstoječe datoteke",
"Which files do you want to keep?" => "Katare datoteke želite ohraniti?",
"If you select both versions, the copied file will have a number added to its name." => "Če izberete obe različici, bo kopirani datoteki k imenu dodana številka.",
"Cancel" => "Prekliči",
"Continue" => "Nadaljuj",
"(all selected)" => "(vse izbrano)",
"({count} selected)" => "({count} izbranih)",
"Error loading file exists template" => "Napaka nalaganja predloge obstoječih datotek",
"Very weak password" => "Zelo šibko geslo",
"Weak password" => "Šibko geslo",
"So-so password" => "Slabo geslo",
"Good password" => "Dobro geslo",
"Strong password" => "Odlično geslo",
"Shared" => "V souporabi",
"Shared by {owner}" => "Souporabo omogoča {owner}",
"Share" => "Souporaba",
"Error" => "Napaka",
"Error while sharing" => "Napaka med souporabo",
"Error while unsharing" => "Napaka med odstranjevanjem souporabe",
"Error while changing permissions" => "Napaka med spreminjanjem dovoljenj",
"Shared with you and the group {group} by {owner}" => "V souporabi z vami in skupino {group}. Lastnik je {owner}.",
"Shared with you by {owner}" => "V souporabi z vami. Lastnik je {owner}.",
"Share with user or group …" => "Souporaba z uporabnikom ali skupino ...",
"Share link" => "Povezava za prejem",
"Password protect" => "Zaščiti z geslom",
"Choose a password for the public link" => "Izberite geslo za javno povezavo",
"Allow Public Upload" => "Dovoli javno pošiljanje na strežnik",
"Email link to person" => "Posreduj povezavo po elektronski pošti",
"Send" => "Pošlji",
"Set expiration date" => "Nastavi datum preteka",
"Expiration date" => "Datum preteka",
"Share via email:" => "Pošlji povezavo do dokumenta preko elektronske pošte:",
"No people found" => "Ni najdenih uporabnikov",
"group" => "skupina",
"Resharing is not allowed" => "Nadaljnja souporaba ni dovoljena",
"Shared in {item} with {user}" => "V souporabi v {item} z uporabnikom {user}",
"Unshare" => "Prekliči souporabo",
"notify by email" => "obvesti po elektronski pošti",
"can share" => "lahko omogoči souporabo",
"can edit" => "lahko ureja",
"access control" => "nadzor dostopa",
"create" => "ustvari",
"update" => "posodobi",
"delete" => "izbriše",
"Password protected" => "Zaščiteno z geslom",
"Error unsetting expiration date" => "Napaka brisanja datuma preteka",
"Error setting expiration date" => "Napaka nastavljanja datuma preteka",
"Sending ..." => "Pošiljanje ...",
"Email sent" => "Elektronska pošta je poslana",
"Warning" => "Opozorilo",
"The object type is not specified." => "Vrsta predmeta ni podana.",
"Enter new" => "Vnesite novo",
"Delete" => "Izbriši",
"Add" => "Dodaj",
"Edit tags" => "Uredi oznake",
"Error loading dialog template: {error}" => "Napaka nalaganja predloge pogovornega okna: {error}",
"No tags selected for deletion." => "Ni izbranih oznak za izbris.",
"Updating {productName} to version {version}, this may take a while." => "Poteka posodabljanje {productName} na različico {version}. Opravilo je lahko dolgotrajno.",
"Please reload the page." => "Stran je treba ponovno naložiti",
"The update was unsuccessful." => "Posodobitev je spodletela",
"The update was successful. Redirecting you to ownCloud now." => "Posodobitev je uspešno končana. Stran bo preusmerjena na oblak ownCloud.",
"%s password reset" => "Ponastavitev gesla %s",
"Use the following link to reset your password: {link}" => "Za ponastavitev gesla uporabite povezavo: {link}",
"You will receive a link to reset your password via Email." => "Na elektronski naslov boste prejeli povezavo za ponovno nastavitev gesla.",
"Username" => "Uporabniško ime",
"Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" => "Datoteke so šifrirane. Če niste omogočili ključa za obnovitev, žal podatkov ne bo mogoče pridobiti nazaj, ko boste geslo enkrat spremenili. Če niste prepričani, kaj storiti, se obrnite na skrbnika storitve. Ali ste prepričani, da želite nadaljevati?",
"Yes, I really want to reset my password now" => "Da, potrjujem ponastavitev gesla",
"Reset" => "Ponastavi",
"New password" => "Novo geslo",
"New Password" => "Novo geslo",
"Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " => "Sistem Mac OS X ni podprt, zato %s ne bo deloval zanesljivo v tem okolju. Program uporabljate na lastno odgovornost! ",
"For the best results, please consider using a GNU/Linux server instead." => "Za najbolj še rezultate je priporočljivo uporabljati strežnik GNU/Linux.",
"Personal" => "Osebno",
"Users" => "Uporabniki",
"Apps" => "Programi",
"Admin" => "Skrbništvo",
"Help" => "Pomoč",
"Error loading tags" => "Napaka nalaganja oznak",
"Tag already exists" => "Oznaka že obstaja",
"Error deleting tag(s)" => "Napaka brisanja oznak",
"Error tagging" => "Napaka označevanja",
"Error untagging" => "Napaka odstranjevanja oznak",
"Error favoriting" => "Napaka označevanja priljubljenosti",
"Error unfavoriting" => "Napaka odstranjevanja oznake priljubljenosti",
"Access forbidden" => "Dostop je prepovedan",
"Cloud not found" => "Oblaka ni mogoče najti",
"Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" => "Pozdravljeni,\n\noseba %s vam je omogočila souporabo %s.\nVir si lahko ogledate: %s\n\n",
"The share will expire on %s." => "Povezava souporabe bo potekla %s.",
"Cheers!" => "Na zdravje!",
"Security Warning" => "Varnostno opozorilo",
"Your PHP version is vulnerable to the NULL Byte attack (CVE-2006-7243)" => "Uporabljena različica PHP je ranljiva za napad NULL Byte (CVE-2006-7243)",
"Please update your PHP installation to use %s securely." => "Za varno uporabo storitve %s, je treba posodobiti namestitev PHP",
"No secure random number generator is available, please enable the PHP OpenSSL extension." => "Na voljo ni nobenega varnega ustvarjalnika naključnih števil. Omogočiti je treba razširitev PHP OpenSSL.",
"Without a secure random number generator an attacker may be able to predict password reset tokens and take over your account." => "Brez varnega ustvarjalnika naključnih števil je mogoče napovedati žetone za ponastavitev gesla, s čimer je mogoče prevzeti nadzor nad računom.",
"Your data directory and files are probably accessible from the internet because the .htaccess file does not work." => "Podatkovna mapa in datoteke so najverjetneje javno dostopni preko interneta, saj datoteka .htaccess ni ustrezno nastavljena.",
"For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." => "Za več informacij o pravilnem nastavljanju strežnika, kliknite na povezavo do <a href=\"%s\" target=\"_blank\">dokumentacije</a>.",
"Create an <strong>admin account</strong>" => "Ustvari <strong>skrbniški račun</strong>",
"Password" => "Geslo",
"Storage & database" => "Shramba in podatkovna zbirka",
"Data folder" => "Podatkovna mapa",
"Configure the database" => "Nastavi podatkovno zbirko",
"Database user" => "Uporabnik podatkovne zbirke",
"Database password" => "Geslo podatkovne zbirke",
"Database name" => "Ime podatkovne zbirke",
"Database tablespace" => "Razpredelnica podatkovne zbirke",
"Database host" => "Gostitelj podatkovne zbirke",
"Finish setup" => "Končaj nastavitev",
"Finishing …" => "Poteka zaključevanje opravila ...",
"This application requires JavaScript to be enabled for correct operation.  Please <a href=\"http://enable-javascript.com/\" target=\"_blank\">enable JavaScript</a> and re-load this interface." => "Program zahteva omogočeno skriptno podporo. Za pravilno delovanje je treba omogočiti <a href=\"http://enable-javascript.com/\" target=\"_blank\">JavaScript</a> in nato ponovno osvežiti vmesnik.",
"%s is available. Get more information on how to update." => "%s je na voljo. Pridobite več podrobnosti za posodobitev.",
"Log out" => "Odjava",
"Automatic logon rejected!" => "Samodejno prijavljanje je zavrnjeno!",
"If you did not change your password recently, your account may be compromised!" => "V primeru, da gesla za dostop že nekaj časa niste spremenili, je račun lahko ogrožen!",
"Please change your password to secure your account again." => "Spremenite geslo za izboljšanje zaščite računa.",
"Server side authentication failed!" => "Overitev s strežnika je spodletela!",
"Please contact your administrator." => "Stopite v stik s skrbnikom sistema.",
"remember" => "zapomni si",
"Log in" => "Prijava",
"Alternative Logins" => "Druge prijavne možnosti",
"Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" => "Pozdravljeni,<br><br>uporabnik %s vam je omogočil souporabo <strong>%s</strong>.<br><a href=\"%s\">Oglejte si vsebino!</a><br><br>",
"This ownCloud instance is currently in single user mode." => "Ta seja oblaka ownCloud je trenutno v načinu enega sočasnega uporabnika.",
"This means only administrators can use the instance." => "To pomeni, da lahko oblak uporabljajo le osebe s skrbniškimi dovoljenji.",
"Contact your system administrator if this message persists or appeared unexpectedly." => "Stopite v stik s skrbnikom sistema, če se bo sporočilo še naprej nepričakovano prikazovalo.",
"Thank you for your patience." => "Hvala za potrpežljivost!",
"The following apps will be disabled:" => "Navedeni programi bodo onemogočeni:",
"The theme %s has been disabled." => "Tema %s je onemogočena za uporabo.",
"Start update" => "Začni posodobitev",
"This ownCloud instance is currently being updated, which may take a while." => "Nastavitev oblaka ownCloud se trenutno posodablja. Opravilo je lahko dolgotrajno ...",
"Please reload this page after a short time to continue using ownCloud." => "Ponovno naložite to stran po krajšem preteku časa in nadaljujte z uporabo oblaka ownCloud.",
"File not found" => "Datoteke ni mogoče najti",
"The specified document has not been found on the server." => "Določenega dokumenta na strežniku ni mogoče najti.",
"You can click here to return to %s." => "S klikom na povezavo boste vrnjeni na %s.",
);
$PLURAL_FORMS = "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);";

==> owncloud_7.0.13~dfsg.orig.tar.bz2: owncloud/core/l10n/sl.php <==
<?php
$TRANSLATIONS = array(
"Expiration date is in the past." => "Datum preteka je v preteklosti.",
"Couldn't send mail to following users: %s " => "Ni mogoče poslati sporočila za: %s",
"Turned on maintenance mode" => "Vzdrževalni način je omogočen",
"Turned off maintenance mode" => "Vzdrževalni način je onemogočen",
"Updated database" => "Posodobljena podatkovna zbirka",
"Disabled incompatible apps: %s" => "Onemogočeni neskladni programi: %s",
"No image or file provided" => "Ni podane datoteke ali slike",
"Unknown filetype" => "Neznana vrsta datoteke",
"Invalid image" => "Neveljavna slika",
"No temporary profile picture available, try again" => "Na voljo ni nobene začasne slike za profil. Poskusite znova.",
"No crop data provided" => "Ni podanih podatkov obreza",
"Sunday" => "nedelja",
"Monday" => "ponedeljek",
"Tuesday" => "torek",
"Wednesday" => "sreda",
"Thursday" => "četrtek",
"Friday" => "petek",
"Saturday" => "sobota",
"January" => "januar",
"February" => "februar",
"March" => "marec",
"April" => "april",
"May" => "maj",
"June" => "junij",
"July" => "julij",
"August" => "avgust",
"September" => "september",
"October" => "oktober",
"November" => "november",
"December" => "december",
"Settings" => "Nastavitve",
"File" => "Datoteka",
"Folder" => "Mapa",
"Image" => "Slika",
"Audio" => "Zvok",
"Saving..." => "Poteka shranjevanje ...",
"seconds ago" => "pred nekaj sekundami",
"_%n minute ago_::_%n minutes ago_" => array("pred %n minuto","pred %n minutama","pred %n minutami","pred %n minutami"),
"_%n hour ago_::_%n hours ago_" => array("pred %n uro","pred %n urama","pred %n urami","pred %n urami"),
"today" => "danes",
"yesterday" => "včeraj",
"_%n day ago_::_%n days ago_" => array("pred %n dnevom","pred %n dnevoma","pred %n dnevi","pred %n dnevi"),
"last month" => "zadnji mesec",
"_%n month ago_::_%n months ago_" => array("pred %n mesecem","pred %n mesecema","pred %n meseci","pred %n meseci"),
"last year" => "lansko leto",
"years ago" => "let nazaj",
"Reset password" => "Ponastavi geslo",
"Password can not be changed. Please contact your administrator." => "Gesla ni mogoče spremeniti. Stopite v stik s skrbnikom.",
"Yes" => "Da",
"No" => "Ne",
"Choose" => "Izbor",
"Error loading file picker template: {error}" => "Napaka nalaganja predloge izbirnika datotek: {error}",
"Ok" => "V redu",
"Error loading message template: {error}" => "Napaka nalaganja predloge sporočil: {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} spor datotek","{count} spora datotek","{count} spori datotek","{count} sporov datotek"),
"One file conflict" => "En spor datotek",
"New Files" => "Nove datoteke",
"Already existing files" => "Obstoječe datoteke",
"Which files do you want to keep?" => "Katare datoteke želite ohraniti?",
"If you select both versions, the copied file will have a number added to its name." => "Če izberete obe različici, bo kopirani datoteki k imenu dodana številka.",
"Cancel" => "Prekliči",
"Continue" => "Nadaljuj",
"(all selected)" => "(vse izbrano)",
"({count} selected)" => "({count} izbranih)",
"Error loading file exists template" => "Napaka nalaganja predloge obstoječih datotek",
"Very weak password" => "Zelo šibko geslo",
"Weak password" => "Šibko geslo",
"So-so password" => "Slabo geslo",
"Good password" => "Dobro geslo",
"Strong password" => "Odlično geslo",
"Shared" => "V souporabi",
"Shared by {owner}" => "Souporabo omogoča {owner}",
"Share" => "Souporaba",
"Error" => "Napaka",
"Error while sharing" => "Napaka med souporabo",
"Error while unsharing" => "Napaka med odstranjevanjem souporabe",
"Error while changing permissions" => "Napaka med spreminjanjem dovoljenj",
"Shared with you and the group {group} by {owner}" => "V souporabi z vami in skupino {group}. Lastnik je {owner}.",
"Shared with you by {owner}" => "V souporabi z vami. Lastnik je {owner}.",
"Share with user or group …" => "Souporaba z uporabnikom ali skupino ...",
"Share link" => "Povezava za prejem",
"Password protect" => "Zaščiti z geslom",
"Choose a password for the public link" => "Izberite geslo za javno povezavo",
"Allow Public Upload" => "Dovoli javno pošiljanje na strežnik",
"Email link to person" => "Posreduj povezavo po elektronski pošti",
"Send" => "Pošlji",
"Set expiration date" => "Nastavi datum preteka",
"Expiration date" => "Datum preteka",
"Share via email:" => "Pošlji povezavo do dokumenta preko elektronske pošte:",
"No people found" => "Ni najdenih uporabnikov",
"group" => "skupina",
"Resharing is not allowed" => "Nadaljnja souporaba ni dovoljena",
"Shared in {item} with {user}" => "V souporabi v {item} z uporabnikom {user}",
"Unshare" => "Prekliči souporabo",
"notify by email" => "obvesti po elektronski pošti",
"can share" => "lahko omogoči souporabo",
"can edit" => "lahko ureja",
"access control" => "nadzor dostopa",
"create" => "ustvari",
"update" => "posodobi",
"delete" => "izbriše",
"Password protected" => "Zaščiteno z geslom",
"Error unsetting expiration date" => "Napaka brisanja datuma preteka",
"Error setting expiration date" => "Napaka nastavljanja datuma preteka",
"Sending ..." => "Pošiljanje ...",
"Email sent" => "Elektronska pošta je poslana",
"Warning" => "Opozorilo",
"The object type is not specified." => "Vrsta predmeta ni podana.",
"Enter new" => "Vnesite novo",
"Delete" => "Izbriši",
"Add" => "Dodaj",
"Edit tags" => "Uredi oznake",
"Error loading dialog template: {error}" => "Napaka nalaganja predloge pogovornega okna: {error}",
"No tags selected for deletion." => "Ni izbranih oznak za izbris.",
"Updating {productName} to version {version}, this may take a while." => "Poteka posodabljanje {productName} na različico {version}. Opravilo je lahko dolgotrajno.",
"Please reload the page." => "Stran je treba ponovno naložiti",
"The update was unsuccessful." => "Posodobitev je spodletela",
"The update was successful. Redirecting you to ownCloud now." => "Posodobitev je uspešno končana. Stran bo preusmerjena na oblak ownCloud.",
"%s password reset" => "Ponastavitev gesla %s",
"Use the following link to reset your password: {link}" => "Za ponastavitev gesla uporabite povezavo: {link}",
"You will receive a link to reset your password via Email." => "Na elektronski naslov boste prejeli povezavo za ponovno nastavitev gesla.",
"Username" => "Uporabniško ime",
"Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" => "Datoteke so šifrirane. Če niste omogočili ključa za obnovitev, žal podatkov ne bo mogoče pridobiti nazaj, ko boste geslo enkrat spremenili. Če niste prepričani, kaj storiti, se obrnite na skrbnika storitve. Ali ste prepričani, da želite nadaljevati?",
"Yes, I really want to reset my password now" => "Da, potrjujem ponastavitev gesla",
"Reset" => "Ponastavi",
"New password" => "Novo geslo",
"New Password" => "Novo geslo",
"Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " => "Sistem Mac OS X ni podprt, zato %s ne bo deloval zanesljivo v tem okolju. Program uporabljate na lastno odgovornost! ",
"For the best results, please consider using a GNU/Linux server instead." => "Za najbolj še rezultate je priporočljivo uporabljati strežnik GNU/Linux.",
"Personal" => "Osebno",
"Users" => "Uporabniki",
"Apps" => "Programi",
"Admin" => "Skrbništvo",
"Help" => "Pomoč",
"Error loading tags" => "Napaka nalaganja oznak",
"Tag already exists" => "Oznaka že obstaja",
"Error deleting tag(s)" => "Napaka brisanja oznak",
"Error tagging" => "Napaka označevanja",
"Error untagging" => "Napaka odstranjevanja oznak",
"Error favoriting" => "Napaka označevanja priljubljenosti",
"Error unfavoriting" => "Napaka odstranjevanja oznake priljubljenosti",
"Access forbidden" => "Dostop je prepovedan",
"Cloud not found" => "Oblaka ni mogoče najti",
"Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" => "Pozdravljeni,\n\noseba %s vam je omogočila souporabo %s.\nVir si lahko ogledate: %s\n\n",
"The share will expire on %s." => "Povezava souporabe bo potekla %s.",
"Cheers!" => "Na zdravje!",
"Security Warning" => "Varnostno opozorilo",
"Your PHP version is vulnerable to the NULL Byte attack (CVE-2006-7243)" => "Uporabljena različica PHP je ranljiva za napad NULL Byte (CVE-2006-7243)",
"Please update your PHP installation to use %s securely." => "Za varno uporabo storitve %s, je treba posodobiti namestitev PHP",
"No secure random number generator is available, please enable the PHP OpenSSL extension." => "Na voljo ni nobenega varnega ustvarjalnika naključnih števil. Omogočiti je treba razširitev PHP OpenSSL.",
"Without a secure random number generator an attacker may be able to predict password reset tokens and take over your account." => "Brez varnega ustvarjalnika naključnih števil je mogoče napovedati žetone za ponastavitev gesla, s čimer je mogoče prevzeti nadzor nad računom.",
"Your data directory and files are probably accessible from the internet because the .htaccess file does not work." => "Podatkovna mapa in datoteke so najverjetneje javno dostopni preko interneta, saj datoteka .htaccess ni ustrezno nastavljena.",
"For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." => "Za več informacij o pravilnem nastavljanju strežnika, kliknite na povezavo do <a href=\"%s\" target=\"_blank\">dokumentacije</a>.",
"Create an <strong>admin account</strong>" => "Ustvari <strong>skrbniški račun</strong>",
"Password" => "Geslo",
"Storage & database" => "Shramba in podatkovna zbirka",
"Data folder" => "Podatkovna mapa",
"Configure the database" => "Nastavi podatkovno zbirko",
"Database user" => "Uporabnik podatkovne zbirke",
"Database password" => "Geslo podatkovne zbirke",
"Database name" => "Ime podatkovne zbirke",
"Database tablespace" => "Razpredelnica podatkovne zbirke",
"Database host" => "Gostitelj podatkovne zbirke",
"Finish setup" => "Končaj nastavitev",
"Finishing …" => "Poteka zaključevanje opravila ...",
"This application requires JavaScript to be enabled for correct operation.  Please <a href=\"http://enable-javascript.com/\" target=\"_blank\">enable JavaScript</a> and re-load this interface." => "Program zahteva omogočeno skriptno podporo. Za pravilno delovanje je treba omogočiti <a href=\"http://enable-javascript.com/\" target=\"_blank\">JavaScript</a> in nato ponovno osvežiti vmesnik.",
"%s is available. Get more information on how to update." => "%s je na voljo. Pridobite več podrobnosti za posodobitev.",
"Log out" => "Odjava",
"Automatic logon rejected!" => "Samodejno prijavljanje je zavrnjeno!",
"If you did not change your password recently, your account may be compromised!" => "V primeru, da gesla za dostop že nekaj časa niste spremenili, je račun lahko ogrožen!",
"Please change your password to secure your account again." => "Spremenite geslo za izboljšanje zaščite računa.",
"Server side authentication failed!" => "Overitev s strežnika je spodletela!",
"Please contact your administrator." => "Stopite v stik s skrbnikom sistema.",
"remember" => "zapomni si",
"Log in" => "Prijava",
"Alternative Logins" => "Druge prijavne možnosti",
"Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" => "Pozdravljeni,<br><br>uporabnik %s vam je omogočil souporabo <strong>%s</strong>.<br><a href=\"%s\">Oglejte si vsebino!</a><br><br>",
"This ownCloud instance is currently in single user mode." => "Ta seja oblaka ownCloud je trenutno v načinu enega sočasnega uporabnika.",
"This means only administrators can use the instance." => "To pomeni, da lahko oblak uporabljajo le osebe s skrbniškimi dovoljenji.",
"Contact your system administrator if this message persists or appeared unexpectedly." => "Stopite v stik s skrbnikom sistema, če se bo sporočilo še naprej nepričakovano prikazovalo.",
"Thank you for your patience." => "Hvala za potrpežljivost!",
"The following apps will be disabled:" => "Navedeni programi bodo onemogočeni:",
"The theme %s has been disabled." => "Tema %s je onemogočena za uporabo.",
"Start update" => "Začni posodobitev",
"This ownCloud instance is currently being updated, which may take a while." => "Nastavitev oblaka ownCloud se trenutno posodablja. Opravilo je lahko dolgotrajno ...",
"Please reload this page after a short time to continue using ownCloud." => "Ponovno naložite to stran po krajšem preteku časa in nadaljujte z uporabo oblaka ownCloud.",
"File not found" => "Datoteke ni mogoče najti",
"The specified document has not been found on the server." => "Določenega dokumenta na strežniku ni mogoče najti.",
"You can click here to return to %s." => "S klikom na povezavo boste vrnjeni na %s.",
"To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" => "Za razreševanje časovnih zahtev večjih namestitev lahko uporabite ukaz iz namestitvene mape:",
);
$PLURAL_FORMS = "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);";
